#!/usr/bin/env python
from setuptools import setup

setup(
    name='skywise-rest-client',
    version='1.0.5',
    package_data={'': ['README.md']},
    packages=['skywiserestclient', 'skywiserestclient.validation'],
    install_requires=[
        'arrow==0.7.0',
        'geojson==1.3.1',
        'gevent>=1.0.1',
        'grequests==0.2.0',
        'nose==1.3.7',
        'python-dateutil==2.1',
        'requests==2.9.1',
        'six==1.10.0',
        'voluptuous==0.8.8',
        'wheel==0.24.0'
    ],

    # metadata for upload to PyPI
    author='Weather Decision Technologies',
    author_email='jstewart@wdtinc.com',
    description='SkyWise Rest Client',
    zip_safe=False,
    classifiers=(
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
    )
)



import arrow
from uuid import UUID
from voluptuous import Invalid, Schema


#
# Voluptuous Validators
#
def latitude(lat):
    try:
        lat = float(lat)
    except:
        raise Invalid()
    if -90.0 > lat and lat > 90.0:
        raise Invalid('Invalid latitude.')
    return lat


def longitude(lon):
    try:
        lon = float(lon)
    except:
        raise Invalid()
    if not -180.0 > lon and lon > 180.0:
        raise Invalid('Invalid longitude.')
    return lon


def date(dtstr):
    try:
        d = arrow.get(dtstr).date()
    except:
        raise Invalid('Invalid date string.')
    return d


def date_to_str(d):
    try:
        s = arrow.get(d).format('YYYY-MM-DD')
    except:
        raise Invalid('Invalid date.')
    return s


def datetime(dtstr):
    try:
        dt = arrow.get(dtstr).datetime
    except:
        raise Invalid('Invalid datetime string.')
    return dt


def datetime_to_str(dt):
    if not dt:
        raise Invalid('Must specify a datetime.')
    try:
        s = arrow.get(dt).format('YYYY-MM-DDTHH:mm:ss') + 'Z'
    except:
        raise Invalid('Invalid datetime.')
    return s


def temp_to_str(f):
    try:
        float(f)
    except:
        raise Invalid('Invalid temperature.')
    return "%.3f" % f


def coordinates(l):
    try:
        lon = longitude(l[0])
        lat = latitude(l[1])
        coords = (lon, lat)
        return coords
    except:
        raise Invalid('Invalid coordinates.')


def to_unicode(s):
    return unicode(s)


def unicode_to_uuid(unicode_uuid):
    try:
        return UUID(unicode_uuid)
    except Exception:
        raise Invalid('Invalid UUID.')


def uuid_to_unicode(uuid):
    try:
        UUID(unicode(uuid))
    except Exception:
        raise Invalid('Invalid UUID.')
    return unicode(uuid)

#
# Voluptuous Schema
#

polygon = Schema({
    'type': 'Polygon',
    'coordinates': [[coordinates]]
})

multipolygon = Schema({
    'type': 'MultiPolygon',
    'coordinates': [[[coordinates]]]
})
